# <div align="center"> **NITEC: Versatile Hand-Annotated Eye Contact Dataset for Ego-Vision Interaction (Accepted at WACV24)** </div>

<p align="center">
  <img src="https://github.com/thohemp/archive/blob/main/nitec.gif" alt="animated" />
</p>

## **Citing**

If you find our work useful, please cite the paper:

```BibTeX
@misc{hempel2023nitec,
      title={NITEC: Versatile Hand-Annotated Eye Contact Dataset for Ego-Vision Interaction}, 
      author={Thorsten Hempel and Magnus Jung and Ahmed A. Abdelrahman and Ayoub Al-Hamadi},
      year={2023},
      eprint={2311.04505},
      archivePrefix={arXiv},
      primaryClass={cs.CV}
}
```
## <div align="center"> **Paper**</div>
> [Thorsten Hempel, Magnus Jung, Ahmed A. Abdelrahman and Ayoub Al-Hamadi, "NITEC: Versatile Hand-Annotated Eye Contact Dataset for Ego-Vision Interaction", *accepted at WACV 2024*.](https://arxiv.org/abs/2311.04505)

## <div align="center"> **Abstract**</div>
>Eye contact is a crucial non-verbal interaction modality and plays an important role in our everyday social life. While humans are very sensitive to eye contact, the capabilities of machines to capture a person's gaze are still mediocre. We tackle this challenge and present NITEC, a hand-annotated eye contact dataset for ego-vision interaction. NITEC exceeds existing datasets for ego-vision eye contact in size and variety of demographics, social contexts, and lighting conditions, making it a valuable resource for advancing ego-vision-based eye contact research. Our extensive evaluations on NITEC demonstrate strong cross-dataset performance, emphasizing its effectiveness and adaptability in various scenarios, that allows seamless utilization to the fields of computer vision, human-computer interaction, and social robotics. We make our NITEC dataset publicly available to foster reproducibility and further exploration in the field of ego-vision interaction.


# Dataset Preparation, Models and further scripts will be published soon.
